/*
 * file ReadWritePropertiesDemo.java
 * 
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM - you are allowed to copy, modify and 
 * redistribute this file as part of any program that interfaces with 
 * IBM Rational CM API.
 *
 * com.ibm.rational.stp.client.samples.ReadWritePropertiesDemo
 *
 * (C) Copyright IBM Corporation 2008, 2010.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.cmapi.samples.cc;

import javax.wvcm.PropertyRequestItem.PropertyRequest;

import com.ibm.rational.wvcm.stp.cc.CcProvider;
import com.ibm.rational.wvcm.stp.cc.CcRegistryRegion;
import com.ibm.rational.wvcm.stp.cc.CcStream;
import com.ibm.rational.wvcm.stp.cc.CcVobTag;

/**
 * Demonstrate how to read and write properties of ClearCase resources,
 * including the use of nested property requests.
 */
public class ReadWritePropertiesDemo extends CcDemoBase {

    private UcmHelper m_ucmHelper;
    private CcStream m_stream;
    private CcProvider m_provider;

    protected void setUp() throws Exception {
        super.setUp();
        m_provider = getClearCaseProvider();
        m_ucmHelper = new UcmHelper(this);
        m_stream = m_ucmHelper.getUcmIntegrationStream();
    }

    /**
     * Demonstrate property request basics by reading several properties
     * of a UCM stream.
     */
    public void testReadProperties() throws Exception {

        // Instantiate a property request.
        // This particular request is for several different stream properties.
        PropertyRequest wantedProps = new PropertyRequest(
                CcStream.CREATOR_LOGIN_NAME,
                CcStream.CREATION_DATE,
                CcStream.DISPLAY_NAME
        );

        m_stream = (CcStream) m_stream.doReadProperties(wantedProps);

        trace("Stream name:          " + m_stream.getDisplayName());
        trace("Stream created by:    " + m_stream.getCreatorLoginName());
        trace("Stream creation date: " + m_stream.getCreationDate());
    }

    public void testReadNestedProperties() throws Exception {

        // Get the default CC registry region
        CcRegistryRegion defaultRegion =
            m_provider.doGetDefaultCcRegistryRegion(null);

        // Construct nested property request for getting interesting properties
        // of all the VOB tags in the registry.
        PropertyRequest wantedProps = new PropertyRequest(
                CcRegistryRegion.VOB_TAG_LIST.nest(
                        CcVobTag.DISPLAY_NAME,
                        CcVobTag.IS_PUBLIC,
                        CcVobTag.IS_PROJECT_VOB));

        // Fetch those properties.
        defaultRegion = (CcRegistryRegion) defaultRegion.doReadProperties(wantedProps);

        // And print the results
        for (CcVobTag vobTag : defaultRegion.getVobTagList()) {
            String tagStr = vobTag.getDisplayName();
            if (vobTag.getIsPublic()) {
                tagStr = tagStr + " (public)";
            }
            if (vobTag.getIsProjectVob()) {
                tagStr = tagStr + " (pvob)";
            }
            trace(tagStr);
        }

        // Bonus points if you know why this code throws an exception.
        try {
            trace("Default region: " + defaultRegion.getDisplayName());
        } catch (Exception ex){
            trace("Got exception trying to get display name property");
        }
    }
}
